#ifndef _JAST_OUTPUT_BODY_ICE_
#define _JAST_OUTPUT_BODY_ICE_

#include <jast/common/Coordinates.ice>

module jast
{
    module output
    {
        /**
          The robot hands
         **/
        enum Hand
        {
            HandLeft,
            HandRight,
            HandAny
        };

        /**
          Indicates that the operation failed for some other reason.
         **/
        exception OperationFailure
        {
            string details;
        };

        /**
          Indicates that the target was out of reach.
         **/
        exception CoordsOutOfReach extends OperationFailure
        {
            ::jast::common::TableCoordinates coords;
        };

        /**
          Indicates that the operation was interrupted.
         **/
        exception OperationAborted extends OperationFailure
        {
        };

        /**
          Methods to control the robot arms.
         **/
        interface Body
        {
            ["ami"] void close(Hand h) throws OperationFailure;

            double getGripperWidth(Hand h);

            ["ami"] void give(Hand h) throws OperationFailure;

            ["ami"] void insert(Hand h) throws OperationFailure;

            bool isReachable(Hand h, ::jast::common::TableCoordinates coords);

            ["ami"] void moveaway() throws OperationFailure;

            ["ami"] void open(Hand h) throws OperationFailure;

            ["ami"] void pickUp(Hand h, ::jast::common::TableCoordinates coords) throws OperationFailure;

            ["ami"] void point(Hand h, ::jast::common::TableCoordinates coords) throws OperationFailure;

            ["ami"] void pointAtWorld(Hand h, ::jast::common::WorldCoordinates coords) throws OperationFailure;

            ["ami"] void putDown(Hand h, ::jast::common::TableCoordinates coords) throws OperationFailure;

            ["ami"] void screw(Hand h) throws OperationFailure;

            ["ami"] void show(Hand h) throws OperationFailure;

            void stop();

            ["ami"] void take(Hand h) throws OperationFailure;
        };
    };
};

#endif // _JAST_OUTPUT_BODY_ICE_
